cloud_inquisitor\.plugins\.collectors\.aws
------------------------------------------

.. automodule:: cloud_inquisitor.plugins.collectors.aws
    :members:
    :no-undoc-members:
    :show-inheritance:
